#ifndef NT2_INCLUDE_CONSTANTS_SQRTPIO_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_SQRTPIO_2_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/sqrtpio_2.hpp>

#endif
